@@ -1,10 +1,9 @@
-from yaml_worker import YamlDataBaseWorker
 from sql import SQLite, SQL
 
 
 class DBWorker:
 
-    def __init__(self, yaml: YamlDataBaseWorker):
+    def __init__(self, yaml):
         self.db_data = yaml
         self.conn = self.initialize_connection()
         self.db_identifier = f"{self.db_data.db_info['ip']}_{self.db_data.db_info['db_type']}_" \
