@@ -1,4 +1,4 @@
-from src.yamlbase.utils import convert_table_data_from_dict_to_table_obj
+from utils import convert_table_data_from_dict_to_table_obj
 import yaml
 
 
